/*
 *  Copyright (C) 2002-2006  The DOSBox Team
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

// include guard
#ifndef DOSBOX_TCPLPT_H
#define DOSBOX_TCPLPT_H

#include "dosbox.h"
#include "parport.h"
#include "TCPSocket.h"


// Essentially a modified filelpt
class CTCPLPT : public CParallel {
public:
	CTCPLPT (CommandLine* cmd, Bitu nr, Bit8u initIrq);
	~CTCPLPT();
	
	bool InstallationSuccessful;	// check after constructing. If
									// something was wrong, delete it right away.
	
	Bitu Read_PR();
	Bitu Read_COM();
	Bitu Read_SR();

	void Write_PR(Bitu);
	void Write_CON(Bitu);
	void Write_IOSEL(Bitu);
	bool Putchar(Bit8u);
    
	virtual void handleUpperEvent(Bit16u type);
    virtual void handleClose();
private:
    bool OpenSocket();
    
    std::string                ip;
    uint32_t                   port;
    std::unique_ptr<TCPSocket> _socket;

	std::string name;			// name of the thing to open
	bool addLF;					// if set, add line feed after carriage return if not used by app

	Bit8u lastChar;				// used to save the previous character to decide wether to add LF
	const Bit16u* codepage_ptr; // pointer to the translation codepage if not null
    
    Bit8u datareg;
	Bit8u controlreg;
    bool autofeed;
	bool ack;
	Bitu timeout;
	Bitu lastUsedTick;
};

#endif	// include guard
